@@ -18,7 +18,7 @@
 */
 
 #include "kebsearchline.h"
-#include <QDebug>
+#include "keditbookmarks_debug.h"
 #include <QTimer>
 #include <QTreeView>
 #include <QListView>
@@ -54,7 +54,7 @@ public:
     bool keepParentsVisible;
     QString search;
     int queuedSearches;
-    QLinkedList<int> searchColumns;
+    QVector<int> searchColumns;
 };
 
 
@@ -158,7 +158,7 @@ void KViewSearchLine::setKeepParentsVisible(bool v)
     d->keepParentsVisible = v;
 }
 
-void KViewSearchLine::setSearchColumns(const QLinkedList<int> &columns)
+void KViewSearchLine::setSearchColumns(const QVector<int> &columns)
 {
     d->searchColumns = columns;
 }
@@ -222,7 +222,7 @@ bool KViewSearchLine::itemMatches(const QModelIndex & item, const QString &s) co
         int row = item.row();
         QModelIndex parent = item.parent();
         if(!d->searchColumns.isEmpty()) {
-            QLinkedList<int>::const_iterator it, end;
+            QVector<int>::const_iterator it, end;
             end = d->searchColumns.constEnd();
             for(it = d->searchColumns.constBegin(); it != end; ++it)
             {
@@ -407,8 +407,8 @@ void KViewSearchLine::slotColumnsRemoved(const QModelIndex &, int first, int las
         if(d->listView->modelColumn() >= first && d->listView->modelColumn()<= last)
         {
             if(d->listView->modelColumn()>last)
-                qCritical()<<"Columns were removed, the modelColumn() doesn't exist anymore. "
-                           "K4listViewSearchLine can't cope with that."<<endl;
+                qCCritical(KEDITBOOKMARKS_LOG)<<"Columns were removed, the modelColumn() doesn't exist anymore. "
+                           "K4listViewSearchLine can't cope with that.";
             updateSearch();
         }
     }
